@@ -1,14 +1,13 @@
 package Statistics::R::IO::ParserState;
 # ABSTRACT: Current state of the IO parser
-$Statistics::R::IO::ParserState::VERSION = '0.101';
+$Statistics::R::IO::ParserState::VERSION = '1.0';
 use 5.010;
 
-use Moose;
+use Class::Tiny::Antlers;
 use namespace::clean;
 
 has data => (
     is => 'ro',
-    isa => 'ArrayRef',
     default => sub { [] },
 );
 
@@ -23,14 +22,39 @@ has singletons => (
 );
 
 
-around BUILDARGS => sub {
-    my $orig = shift;
-    my $attributes = $orig->(@_);
-    my $x = $attributes->{data};
-    $attributes->{data} = (!ref($x)) ? [split //, $x] : $x;
-    $attributes
-};
+sub BUILDARGS {
+    my $class = shift;
+    my $attributes = {};
+    
+    if ( scalar @_ == 1) {
+        if ( ref $_[0] eq 'HASH' ) {
+            $attributes = $_[0]
+        }
+        else {
+            $attributes->{name} = $_[0]
+        }
+    }
+    elsif ( @_ % 2 ) {
+        die "The new() method for $class expects a hash reference or a key/value list."
+                . " You passed an odd number of arguments\n";
+    }
+    else {
+        $attributes = { @_ };
+    }
 
+    # split strings into a list of individual characters
+    if (defined $attributes->{data} && !ref($attributes->{data})) {
+        $attributes->{data} = [split //, $attributes->{data}];
+    }
+        
+    $attributes
+}
+
+sub BUILD {
+    my $self = shift;
+    
+    die 'foo' unless ref($self->data) eq 'ARRAY'
+}
 
 sub at {
     my $self = shift;
@@ -66,8 +90,6 @@ sub eof {
 }
 
     
-__PACKAGE__->meta->make_immutable;
-
 1;
 
 __END__
@@ -82,7 +104,7 @@ Statistics::R::IO::ParserState - Current state of the IO parser
 
 =head1 VERSION
 
-version 0.101
+version 1.0
 
 =head1 SYNOPSIS
 
@@ -164,13 +186,15 @@ L<Statistics::R::IO> for bug reporting.
 
 See L<Statistics::R::IO> for support and contact information.
 
+=for Pod::Coverage BUILDARGS BUILD
+
 =head1 AUTHOR
 
 Davor Cubranic <cubranic@stat.ubc.ca>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by University of British Columbia.
+This software is Copyright (c) 2016 by University of British Columbia.
 
 This is free software, licensed under:
 
