@@ -1,6 +1,6 @@
 package Statistics::R::IO::QapEncoding;
 # ABSTRACT: Functions for parsing Rserve packets
-$Statistics::R::IO::QapEncoding::VERSION = '0.101';
+$Statistics::R::IO::QapEncoding::VERSION = '1.0';
 use 5.010;
 
 use strict;
@@ -27,6 +27,7 @@ use Statistics::R::REXP::Symbol;
 use Statistics::R::REXP::Null;
 use Statistics::R::REXP::GlobalEnvironment;
 use Statistics::R::REXP::Unknown;
+use Statistics::R::REXP::S4;
 
 use Carp;
 
@@ -152,13 +153,13 @@ sub sexp_data {
         # expression vector
         expsxp($object_info, $attributes)
     } elsif ($object_info->{object_type} == XT_LIST_NOTAG) {
-        # pairlist
-        die "not implemented: $object_info->{object_type}";
+        # pairlist with no tags
+        $object_info->{has_tags} = 0;
         listsxp($object_info)
     } elsif ($object_info->{object_type} == XT_LIST_TAG) {
         # pairlist with tags
         $object_info->{has_tags} = 1;
-        tagged_pairlist($object_info)
+        listsxp($object_info)
     } elsif ($object_info->{object_type} == XT_LANG_NOTAG) {
         # language without tags
         $object_info->{has_tags} = 0;
@@ -176,6 +177,9 @@ sub sexp_data {
     } elsif ($object_info->{object_type} == XT_UNKNOWN) {
         # unknown
         nosxp($object_info, $attributes)
+    } elsif ($object_info->{object_type} == XT_S4) {
+        # unknown
+        s4sxp($object_info, $attributes)
     } else {
         error "unimplemented XT_TYPE: " . $object_info->{object_type}
     }
@@ -207,15 +211,21 @@ sub maybe_attributes {
 
 
 sub tagged_pairlist_to_rexp_hash {
-    my $list = shift;
-    return unless ref $list eq ref [];
+    my $list = shift or return;
+    
+    croak "Tagged element has an attribute?!"
+        if exists $list->{attributes} &&
+        grep {$_ ne 'names'} keys %{$list->{attributes}};
+    
+    my @elements = @{$list->elements};
+    my @names = @{$list->attributes->{names}->elements};
+    die 'length of tags does not match the elements' unless
+        scalar(@elements) == scalar(@names);
 
     my %rexps;
-    foreach my $element (@$list) {
-        croak "Tagged element has an attribute?!"
-            if exists $element->{attribute};
-        my $name = $element->{tag}->name;
-        $rexps{$name} = $element->{value};
+    while (my $name = shift(@names)) {
+        my $value = shift(@elements);
+        $rexps{$name} = $value;
     }
     %rexps
 }
@@ -238,6 +248,24 @@ sub tagged_pairlist_to_attribute_hash {
 }
 
 
+sub s4sxp {
+    my ($object_info, $attributes) = (shift, shift);
+    my $class = $attributes->{class}->elements;
+    croak "S4 'class' must be a single-element array" unless
+        ref($class) eq 'ARRAY' && scalar(@{$class}) == 1;
+    my $package = $attributes->{class}->attributes->{package}->elements;
+    croak "S4 'package' must be a single-element array" unless
+        ref($package) eq 'ARRAY' && scalar(@{$package}) == 1;
+    
+    # the remaining attributes should be object's slots
+    delete $attributes->{class};
+    my $slots = $attributes;
+    
+    mreturn(Statistics::R::REXP::S4->new(class => $class->[0],
+                                         package => $package->[0],
+                                         slots => $slots))
+}
+
 sub symsxp {
     my $object_info = shift;
     
@@ -509,6 +537,41 @@ sub tagged_pairlist {
 }
 
 
+## At the REXP level, pairlists are treated the same as generic
+## vectors, i.e., as instances of type List. Tags, if present, become
+## the name attribute.
+sub listsxp {
+    my $object_info = shift;
+    ## The `tagged_pairlist` returns an array of cons cells, and we
+    ## must separate the tags from the elements before invoking the
+    ## List constructor, with the tags becoming the names attribute
+    bind(tagged_pairlist($object_info),
+         sub {
+             my $list = shift or return;
+
+             my @elements;
+             my @names;
+             foreach my $element (@$list) {
+                 my $tag = $element->{tag};
+                 my $value = $element->{value};
+                 push @elements, $value;
+                 push @names, $tag ? $tag->name : '';
+             }
+
+             my %args = (elements => [ @elements ]);
+             ## if no element is tagged, then don't construct the
+             ## 'names' attribute
+             if (grep {exists $_->{tag}} @$list) {
+                 $args{attributes} =  {
+                     names => Statistics::R::REXP::Character->new([ @names ])
+                 };
+             }
+
+             mreturn(Statistics::R::REXP::List->new(%args))
+         })
+}
+
+
 ## Language expressions are pairlists, but with a certain structure:
 ## - the first element is the reference (name or another language
 ##   expression) to the function call
@@ -516,7 +579,7 @@ sub tagged_pairlist {
 ##   tags to name them
 sub langsxp {
     my ($object_info, $attributes) = (shift, shift);
-    ## After the pairlist has been parsed by `listsxp`, we want to
+    ## After the pairlist has been parsed by `tagged_pairlist`, we
     ## separate the tags from the elements before invoking the Language
     ## constructor, with the tags becoming the names attribute
     bind(tagged_pairlist($object_info),
@@ -629,7 +692,7 @@ Statistics::R::IO::QapEncoding - Functions for parsing Rserve packets
 
 =head1 VERSION
 
-version 0.101
+version 1.0
 
 =head1 SYNOPSIS
 
@@ -692,7 +755,7 @@ C<$obj_info> hash's "object_type" key to use the correct parser for
 the particular type.
 
 =item intsxp, langsxp, lglsxp, listsxp, rawsxp, dblsxp, cplxsxp,
-strsxp, symsxp, vecsxp, expsxp, closxp
+strsxp, symsxp, vecsxp, expsxp, closxp, s4sxp
 
 Parsers for the corresponding R SEXP-types.
 
@@ -747,7 +810,7 @@ Davor Cubranic <cubranic@stat.ubc.ca>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by University of British Columbia.
+This software is Copyright (c) 2016 by University of British Columbia.
 
 This is free software, licensed under:
 
