@@ -1,24 +1,24 @@
 package Statistics::R::REXP::Expression;
 # ABSTRACT: an R expression vector
-$Statistics::R::REXP::Expression::VERSION = '0.101';
+$Statistics::R::REXP::Expression::VERSION = '1.0';
 use 5.010;
 
 use Scalar::Util qw(blessed);
 
-use Moose;
+use Class::Tiny::Antlers;
 use namespace::clean;
 
 extends 'Statistics::R::REXP::List';
 
+use constant sexptype => 'EXPRSXP';
+
 sub to_pl {
     Statistics::R::REXP::Vector::to_pl(@_)
 }
 
-around _type => sub { 'expression' };
+sub _type { 'expression' };
 
 
-__PACKAGE__->meta->make_immutable;
-
 1; # End of Statistics::R::REXP::Expression
 
 __END__
@@ -33,7 +33,7 @@ Statistics::R::REXP::Expression - an R expression vector
 
 =head1 VERSION
 
-version 0.101
+version 1.0
 
 =head1 SYNOPSIS
 
@@ -63,6 +63,10 @@ of its elements.
 
 =over
 
+=item sexptype
+
+SEXPTYPE of expressions is C<EXPRSXP>.
+
 =item to_pl
 
 Perl value of the expression vector is an array reference to the Perl
@@ -91,7 +95,7 @@ Davor Cubranic <cubranic@stat.ubc.ca>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by University of British Columbia.
+This software is Copyright (c) 2016 by University of British Columbia.
 
 This is free software, licensed under:
 
